        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,8,12,13,18,20,21,22,24,27,29,30,31,32,33,36,37,41,42,43,44,48,49,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 16 <br>9,10,11,14,16,19,23,25,26,28,35,38,39,40,45,46';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 5 <br>7,15,17,34,47';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,8,12,13,18,20,21,22,24,27,29,30,31,32,33,36,37,41,42,43,44,48,49,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 16 <br>9,10,11,14,16,19,23,25,26,28,35,38,39,40,45,46';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 5 <br>7,15,17,34,47';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,8,12,13,18,20,21,22,24,27,29,30,31,32,33,36,37,41,42,43,44,48,49,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 16 <br>9,10,11,14,16,19,23,25,26,28,35,38,39,40,45,46';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 5 <br>7,15,17,34,47';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,8,12,13,18,20,21,22,24,27,29,30,31,32,33,36,37,41,42,43,44,48,49,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 16 <br>9,10,11,14,16,19,23,25,26,28,35,38,39,40,45,46';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 5 <br>7,15,17,34,47';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,8,12,13,18,20,21,22,24,27,29,30,31,32,33,36,37,41,42,43,44,48,49,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 16 <br>9,10,11,14,16,19,23,25,26,28,35,38,39,40,45,46';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 5 <br>7,15,17,34,47';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 30 <strong>control</strong><br>0,1,2,3,4,5,6,8,12,13,18,20,21,22,24,27,29,30,31,32,33,36,37,41,42,43,44,48,49,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>14</strong> miembros: 16 <br>9,10,11,14,16,19,23,25,26,28,35,38,39,40,45,46';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260503 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>47</strong> miembros: 5 <br>7,15,17,34,47';}
}
